From: Juergen Gross <jgross@suse.com>
To: Ingo Molnar <mingo@kernel.org>, Eric Biggers <ebiggers3@gmail.com>
Cc: linux-crypto@vger.kernel.org,
Herbert Xu <herbert@gondor.apana.org.au>,
"David S . Miller" <davem@davemloft.net>,
Josh Poimboeuf <jpoimboe@redhat.com>,
Jussi Kivilinna <jussi.kivilinna@iki.fi>,
x86@kernel.org, linux-kernel@vger.kernel.org,
syzkaller-bugs@googlegroups.com,
Eric Biggers <ebiggers@google.com>,
Peter Zijlstra <a.p.zijlstra@chello.nl>
Subject: Re: [PATCH] crypto: x86/twofish-3way - Fix %rbp usage
Date: Tue, 19 Dec 2017 09:04:56 +0100 [thread overview]
Message-ID: <44b42058-c465-4d1e-7710-198754efabe4@suse.com> (raw)
In-Reply-To: <20171219075443.tdpt2l72eelhpi7j@gmail.com>
On 19/12/17 08:54, Ingo Molnar wrote:
>
> * Eric Biggers <ebiggers3@gmail.com> wrote:
>
>> There may be a small overhead caused by replacing 'xchg REG, REG' with
>> the needed sequence 'mov MEM, REG; mov REG, MEM; mov REG, REG' once per
>> round. But, counterintuitively, when I tested "ctr-twofish-3way" on a
>> Haswell processor, the new version was actually about 2% faster.
>> (Perhaps 'xchg' is not as well optimized as plain moves.)
>
> XCHG has implicit LOCK semantics on all x86 CPUs, so that's not a surprising
> result I think.
Exchanging 2 registers can be done without memory access via:
xor reg1, reg2
xor reg2, reg1
xor reg1, reg2
Juergen
next prev parent reply other threads:[~2017-12-19 8:05 UTC|newest]
Thread overview: 11+ messages / expand[flat|nested] mbox.gz Atom feed top
2017-11-28 18:36 WARNING: kernel stack regs has bad 'bp' value (2) syzbot
2017-11-30 9:17 ` Eric Biggers
2017-12-27 18:29 ` Dmitry Vyukov
2017-12-28 7:30 ` Dmitry Vyukov
2017-12-19 0:40 ` [PATCH] crypto: x86/twofish-3way - Fix %rbp usage Eric Biggers
2017-12-19 7:54 ` Ingo Molnar
2017-12-19 8:04 ` Juergen Gross [this message]
2017-12-19 14:37 ` David Laight
2017-12-19 17:35 ` Ingo Molnar
2017-12-19 22:37 ` Josh Poimboeuf
2017-12-28 7:02 ` Herbert Xu
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=44b42058-c465-4d1e-7710-198754efabe4@suse.com \
--to=jgross@suse.com \
--cc=a.p.zijlstra@chello.nl \
--cc=davem@davemloft.net \
--cc=ebiggers3@gmail.com \
--cc=ebiggers@google.com \
--cc=herbert@gondor.apana.org.au \
--cc=jpoimboe@redhat.com \
--cc=jussi.kivilinna@iki.fi \
--cc=linux-crypto@vger.kernel.org \
--cc=linux-kernel@vger.kernel.org \
--cc=mingo@kernel.org \
--cc=syzkaller-bugs@googlegroups.com \
--cc=x86@kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®